# uv-netrc

This crate vendors the [`rust-netrc`](https://crates.io/crates/rust-netrc) parser for use by uv.

The source was vendored from
[`gribouille/netrc`](https://github.com/gribouille/netrc/tree/e5f96cc9cc78931b949b48c0758f15da331e9761),
as published in `rust-netrc` 0.1.2 with checksum
`7e98097f62769f92dbf95fb51f71c0a68ec18a4ee2e70e0d3e4f47ac005d63e9`.

The package is named `uv-netrc`, and the library target is `uv_netrc`.

## License

The vendored source is licensed under MIT. See [LICENSE](./LICENSE).
